@@ -2558,7 +2558,7 @@ gboolean idle_muc_channel_get_members (IdleMUCChannel *obj, GArray ** ret, GErro
 {
 	IdleMUCChannelPrivate *priv = IDLE_MUC_CHANNEL_GET_PRIVATE(obj);
 
-	*ret = idle_handle_set_to_array(priv->local_pending);
+	*ret = idle_handle_set_to_array(priv->current_members);
 	
   return TRUE;
 }
@@ -3072,17 +3072,26 @@ gboolean idle_muc_channel_send (IdleMUCChannel *obj, guint type, const gchar * t
 
 	while (part < final_text+len)
 	{
+		char *br = strchr (part, '\n');
+		size_t len = IRC_MSG_MAXLEN-headerlen;
+		if (br)
+		{
+			len = (len < br - part) ? len : br - part;
+		}
+
 		if (type == TP_CHANNEL_TEXT_MESSAGE_TYPE_ACTION)
 		{
-			g_snprintf(msg+headerlen, IRC_MSG_MAXLEN+1-headerlen, "%s\001", part);
-			
-			part += IRC_MSG_MAXLEN-headerlen-1;
+			g_snprintf(msg+headerlen, len + 1, "%s\001", part);
+			len -= 1;
 		}
 		else
 		{
-			g_strlcpy(msg+headerlen, part, IRC_MSG_MAXLEN+1-headerlen);
-
-			part += IRC_MSG_MAXLEN-headerlen;
+			g_strlcpy(msg+headerlen, part, len + 1);
+		}
+		part += len;
+		if (br)
+		{
+			part++;
 		}
 
 		_idle_connection_send(priv->connection, msg);
