@@ -559,6 +559,13 @@ static void dns_result_callback(guint unused, IdleDNSResult *results, gpointer u
 	int rc = -1;
 	GIOChannel *io_chan;
 
+	if (!results)
+	{
+	  g_debug("%s: no DNS results received", G_STRFUNC);
+	  change_state(conn, SERVER_CONNECTION_STATE_NOT_CONNECTED, SERVER_CONNECTION_STATE_REASON_ERROR);
+	  return;
+	}
+
 	for (cur = results; cur != NULL; cur = cur->ai_next)
 	{
 		fd = socket(cur->ai_family, cur->ai_socktype, cur->ai_protocol);
